==> sherpa_client-0.12.6.tar.gz: sherpa_client-0.12.6/sherpa_client/api/suggesters/patch_suggester.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union, cast

import httpx

from ... import errors
from ...client import Client
from ...models.suggester import Suggester
from ...models.suggester_patch import SuggesterPatch
from ...types import Response


def _get_kwargs(
    project_name: str,
    name: str,
    *,
    client: Client,
    json_body: SuggesterPatch,
) -> Dict[str, Any]:
    url = "{}/projects/{projectName}/suggesters/{name}".format(client.base_url, projectName=project_name, name=name)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "patch",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Union[Any, Suggester]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = Suggester.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = cast(Any, None)
        return response_404
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[Union[Any, Suggester]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_name: str,
    name: str,
    *,
    client: Client,
    json_body: SuggesterPatch,
) -> Response[Union[Any, Suggester]]:
    """Partially update a suggester

    Args:
        project_name (str):
        name (str):
        json_body (SuggesterPatch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, Suggester]]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        name=name,
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_name: str,
    name: str,
    *,
    client: Client,
    json_body: SuggesterPatch,
) -> Optional[Union[Any, Suggester]]:
    """Partially update a suggester

    Args:
        project_name (str):
        name (str):
        json_body (SuggesterPatch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, Suggester]]
    """

    return sync_detailed(
        project_name=project_name,
        name=name,
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    project_name: str,
    name: str,
    *,
    client: Client,
    json_body: SuggesterPatch,
) -> Response[Union[Any, Suggester]]:
    """Partially update a suggester

    Args:
        project_name (str):
        name (str):
        json_body (SuggesterPatch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, Suggester]]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        name=name,
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_name: str,
    name: str,
    *,
    client: Client,
    json_body: SuggesterPatch,
) -> Optional[Union[Any, Suggester]]:
    """Partially update a suggester

    Args:
        project_name (str):
        name (str):
        json_body (SuggesterPatch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, Suggester]]
    """

    return (
        await asyncio_detailed(
            project_name=project_name,
            name=name,
            client=client,
            json_body=json_body,
        )
    ).parsed

==> sherpa_client-1.0.3.tar.gz: sherpa_client-1.0.3/sherpa_client/api/suggesters/patch_suggester.py <==
from http import HTTPStatus
from typing import Any, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.suggester import Suggester
from ...models.suggester_patch import SuggesterPatch
from ...types import Response


def _get_kwargs(
    project_name: str,
    name: str,
    *,
    body: SuggesterPatch,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "patch",
        "url": "/projects/{project_name}/suggesters/{name}".format(
            project_name=project_name,
            name=name,
        ),
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/merge-patch+json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, Suggester]]:
    if response.status_code == 200:
        response_200 = Suggester.from_dict(response.json())

        return response_200
    if response.status_code == 404:
        response_404 = cast(Any, None)
        return response_404
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, Suggester]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_name: str,
    name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: SuggesterPatch,
) -> Response[Union[Any, Suggester]]:
    """Partially update a suggester

    Args:
        project_name (str):
        name (str):
        body (SuggesterPatch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, Suggester]]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        name=name,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_name: str,
    name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: SuggesterPatch,
) -> Optional[Union[Any, Suggester]]:
    """Partially update a suggester

    Args:
        project_name (str):
        name (str):
        body (SuggesterPatch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, Suggester]
    """

    return sync_detailed(
        project_name=project_name,
        name=name,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    project_name: str,
    name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: SuggesterPatch,
) -> Response[Union[Any, Suggester]]:
    """Partially update a suggester

    Args:
        project_name (str):
        name (str):
        body (SuggesterPatch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, Suggester]]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        name=name,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_name: str,
    name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: SuggesterPatch,
) -> Optional[Union[Any, Suggester]]:
    """Partially update a suggester

    Args:
        project_name (str):
        name (str):
        body (SuggesterPatch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, Suggester]
    """

    return (
        await asyncio_detailed(
            project_name=project_name,
            name=name,
            client=client,
            body=body,
        )
    ).parsed
